Learn R Programming

mcrPioda (version 1.3.4)

MCResult.calcPaBaTiesRatio: Calculate PaBa Ties Ratio.

Description

This function computes the ratio of slopes ties values in the classic pairwise PaBa slope calculation. A ratio higher than approx 0.05 may suggest a potential bias risk. In this case data precision is too low for correct PaBa estimation. The function is written in R and can be slow with large data set.

Usage

MCResult.calcPaBaTiesRatio(.Object)

Value

PaBa ties ratio (ties slopes vs total slopes)

Arguments

.Object

object of class "MCResult".