Learn R Programming

mcrPioda (version 1.3.4)

MCResultAnalytical.calcResponse: Calculate Response

Description

Calculate predicted values for given values of the reference-method.

Usage

MCResultAnalytical.calcResponse(.Object, x.levels, alpha = 0.05)

Value

matrix with predicted values with confidence intervals for given values of the reference-method.

Arguments

.Object

object of class 'MCResultAnalytical'

x.levels

numeric vector specifying values of the reference method for which prediction should be made

alpha

significance level for confidence intervals