Compute Resampling T-statistic. for Calculation of t-Bootstrap Confidence Intervals.
mc.calcTstar(
.Object,
x.levels,
iter.max = 30,
threshold = 1e-06,
kM = 1.345,
tauMM = 4.685,
priorSlope = 1,
priorIntercept = 0,
bdPoint = 0.5
)Tstar numeric vector containing resampling pivot statistic.
object of class "MCResultResampling".
a numeric vector of clinical decision points of interest.
maximal number of iterations for calculation of weighted Deming regression.
threshold for calculation of weighted Deming regression.
Huber's k for the M weighting, default kM = 1.345
Tukey's tau for bisquare redescending weighting function, default tauMM = 4,685
starting slope value for PiMMDeming, default priorSlope = 1
starting intercept value for PiMMDeming, default priorIntercept = 0
Proportion of data points selected for the highly robust M regression used for the determination of the starting parameters. Default 0.5
Carpenter J., Bithell J. Bootstrap confidence intervals: when, which, what? A practical guide for medical statisticians. Stat Med, 19 (9), 1141-1164 (2000).